@@ -67,7 +67,7 @@ class Pageable(ABC):
         :param page_size: the size of the page to be returned, must be greater than 0.
         :return: a new :class:`PageRequest`.
         """
-        return PageRequest(page=0, size=page_size)
+        return PageRequest(0, page_size)
 
     @abstractmethod
     def page_number(self) -> int:
@@ -141,7 +141,7 @@ class PageRequest(Pageable):
         self.size = size
 
     def first(self) -> "PageRequest":
-        return PageRequest(page=0, size=self.size)
+        return PageRequest(0, self.size)
 
     def offset(self) -> int:
         return self.page * self.size
@@ -150,7 +150,7 @@ class PageRequest(Pageable):
         return self.page > 0
 
     def next(self) -> "PageRequest":
-        return PageRequest(page=self.page + 1, size=self.size)
+        return PageRequest(self.page + 1, self.size)
 
     def page_number(self) -> int:
         return self.page
@@ -159,12 +159,10 @@ class PageRequest(Pageable):
         return self.size
 
     def previous_or_first(self) -> "PageRequest":
-        return (
-            self if self.page == 0 else PageRequest(page=self.page - 1, size=self.size)
-        )
+        return self if self.page == 0 else PageRequest(self.page - 1, self.size)
 
     def with_page(self, page_number: int) -> "PageRequest":
-        return PageRequest(page=page_number, size=self.size)
+        return PageRequest(page_number, self.size)
 
 
 class Unpaged(Pageable):
